
;                             INIZIALIZZAZIONE
;                             ----------------

	.title  " programma per la gestione di un impianto audio "
;               "   con 1 processore audio tipo x9313"
;                               "9313x5.asm"                                
;       ****************************************************************
;       In questo programma la porta utilizzata per l'ingresso analogico
;        pb0 .- Le porte del registro pa vengono 
;       utilizzate per il trasferimento dei dati al x9313 .
; *********************************************************************
;       PA0 = funzione di up/down
;       PA1 = funzione di incremento
;       PA2 = funzione CS (computer select) 
;       ****************************************************************
;
	.vers   "ST62E10"       ; INDICA IL TIPO DI DISPOSITIVO DA PROGRAMMARE


;****************************************************************************
;*                       VARIABILI DEL MICRO                                *
;****************************************************************************

; Questo elenco di variabili e' STANDARD, cioe' non dovrete mai modificarlo.

;      DEFINIZIONE DEGLI INDIRIZZI DI PARTENZA DELLE VARIE AREE DI MEMORIA
;      -------------------------------------------------------------------

;            DEFINIZIONE DELLE LOCAZIONI DEI 5 REGISTRI DEL MICRO
;            ----------------------------------------------------
a       .def    0ffh    ;ACCUMULATOR (REGISTRO ACCUMULATORE)
x       .def    080h    ;X REGISTER  (REGISTRO X)
y       .def    081h    ;Y REGISTER  (REGISTRO Y)
v       .def    082h    ;V REGISTER  (REGISTRO V)
w       .def    083h    ;W REGISTER  (REGISTRO W)

;              DEFINIZIONE DEI REGISTRI DELLE PORTE
;              ------------------------------------
port_a  .def    0c0h    ;PORT A DATA REGISTER
port_b  .def    0c1h    ;PORT B DATA REGISTER
port_c  .def    0c2h    ;PORT C DATA REGISTER
pdir_a  .def    0c4h    ;PORT A DIRECTION REGISTER  (0=Input   1=Output)
pdir_b  .def    0c5h    ;PORT B DIRECTION REGISTER
pdir_c  .def    0c6h    ;PORT C DIRECTION REGISTER
popt_a  .def    0cch    ;PORT A OPTION REGISTER
popt_b  .def    0cdh    ;PORT B OPTION REGISTER
popt_c  .def    0ceh    ;PORT C OPTION REGISTER

;               DEFINIZIONE DEL REGISTRO DEGLI INTERRUPT
;               ----------------------------------------
ior     .def    0c8h    ;INTERRUPT OPTION REGISTER.

;               DEFINIZIONE DEL REGISTRO PER IL CONVERTITORE A/D
;               ------------------------------------------------
addr    .def    0d0h    ;A/D DATA REGISTER (REGISTRO DATI DEL CONVERTITORE)
adcr    .def    0d1h    ;A/D CONTROL REGISTER (REGISTRO DI CONTROLLO)


;               DEFINIZIONE DEI REGISTRI DEL TIMER
;               ----------------------------------
psc     .def    0d2h    ;TIMER PRESCALER REGISTER (REGISTRO DEL PRESCALER)
tcr     .def    0d3h    ;TIMER DATA REGISTER (REGISTRO DATI)
tscr    .def    0d4h    ;TIMER TSCR REGISTER ( REGISTRO PER IL CONTROLLO
			;DELLO STATO DEL TIMER)

;               DEFINIZIONE DEL REGISTRO PER IL WATCH-DOG
;               -----------------------------------------
wdog    .def    0d8h    ;WATCHDOG REGISTER

;              DEFINIZIONE DEL REGISTRO PER LO SPAZIO DATI ROM
;              -----------------------------------------------
drw     .def    0c9h    ;DATA ROM WINDOW REGISTER

;****************************************************************************
;*                         VARIABILI DEL PROGRAMMA                          *
;****************************************************************************
vol1    .def    087h    ;definisce la variabile vol1

;****************************************************************************
;*                         SETTAGGIO INIZIALE                               *
;****************************************************************************
; Le porte parallele, il timer, il convertitore A/D ed il watch dog debbono
; essere INIZIALIZZATI all'inizio del programma.
; Abbiamo indicato l'operazione di settaggio iniziale con INIZIO.
;             INIZIO DEL PROGRAMMA
;             --------------------
	.org    0880h   ; E' UGUALE IN OGNI PROGRAMMA. NON CAMBIARLO

inizio                  ;  INIZIALIZZAZIONE DELLE PERIFERICHE


	ldi     wdog,0ffh       ; RICARICA IL WATCH DOG
; Questa operazione va ripetuta circa ogni 30 istruzioni per evitare che
; il microprocessore si resetti da solo.

;      SETTAGGIO DELLA PORTA "A" COME OUTPUT PUSH-PULL (10 mA max)
;      -----------------------------------------------------------
	ldi     port_a,00000000b
        ldi     pdir_a,00000111b  ;pa0-pa1-pa2- come USCITE PUSH-PULL
        ldi     popt_a,00000111b  

;      SETTAGGIO DELLA PORTA "B" COME INPUT PULL-UP
;      --------------------------------------------
;    le porte Pb0,...Pb7 sono settate input pull-up
	
	ldi     port_b,00000000b        
	ldi     pdir_b,00000000b  
	ldi     popt_b,00000000b  
; *****************************************************************
	ldi     adcr,0          ;DISABLE A/D INTERRUPT
	ldi     tscr,0          ;DISABLE TIMER INTERRUPT
	ldi     ior,0           ;DISABLE ALL INTERRUPT

	reti                    ;RIPRISTINA I FLAG PRINCIPALI


	jp      main            ;SALTA AL PROGRAMMA PRINCIPALE


;****************************************************************************
;*                       SUBROUTINE DI INTERRUPT                            *
;****************************************************************************

ad_int                  ;INTERRUPT DEL CONVERTITORE A/D
	reti

tim_int                 ;INTERRUPT DEL TIMER
	reti

BC_int                  ;INTERRUPT DELLE PORTE A e B
	reti

A_int                   ;INTERRUPT DELLA PORTA A
	reti

nmi_int                 ;INTERRUPT NON MASCHERABILE
	reti

;****************************************************************************
;*                         SUBROUTINE                                       *
;****************************************************************************
ritardo ldi     wdog,255        ;NOME DELLA SUBROUTINE

	ldi     x,50           ;carica in x il valore 50
rit2    ldi     y,50           ;carica in y il valore 50
rit1    ldi     wdog,255
	dec     y               ;decrementa y
	jrnz    rit1
	dec     x               ;decrementa x
	jrnz    rit2

	ret                     ; ritorna al programma principale.
; **********************
; **********************
abba    ldi     wdog,255        ;ricarica wdog
	res     0,port_a
	nop
	res     1,port_a
	nop     
	call    ritardo
	ret
; **********************
; **********************
alza    ldi     wdog,255        ;ricarica wdog
	set     0,port_a
	nop
	res     1,port_a
	nop
	call    ritardo
	ret
; * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *

voldn   ldi     wdog,255        ;
        cpi     a,0             ;
        jrz     ritdn           ;
        dec     a               ;
;       ld      vol,a           ;
ritdn   ret                     ;

; *
; ***************************
volup   ldi     wdog,255     
        cpi     a,30            ; 
	jrz     ritup           
        inc     a               ;

ritup  ret                      ;ritorna al programma principale
; ***************************
;***************************************************************************
;*                         PROGRAMMA PRINCIPALE                            *
;***************************************************************************

main    ldi     wdog,255        ;IDENTIFICA L'INIZIO DEL PROGRAMMA PRINCIPALE
; *********************************************
	set     0,port_a
	set     1,port_a
	set     2,port_a
        ldi     vol1,0          ;
        call    ritardo         ;    
; ***********************************************************
main1   set     0,port_b        ;settato pb0
	set     0,popt_b        ;come ingresso analogico
	ldi     adcr,00110000b  ;inizia conversione
att1    jrr     6,adcr,att1     ;attendi fine conversione
        ld      a,addr          ;
        res     0,port_b        ;
        res     0,popt_b        ;
; *******************************
	ldi     wdog,255
        cpi     a,100   ;
        jrc     abb1    ;
        cpi     a,200   ;
        jrc     jalz1   ;
        jp      tasto2  ;
jalz1   jp      alz1    ;
; *******************************
abb1    

        ldi     wdog,255;
        ld      a,vol1  ; 
        cpi     a,0     ;
        jrz     h1      ;
        call    voldn   ;
        ld      vol1, a ;
        jp      i1      ;
h1      jp      tasto2  ; 
i1      res     2,port_a
	call    abba
	set     2,port_a
	nop
	set     1,port_a
ndec1   jp      tasto2
; -------------------------------
alz1    

	ldi     wdog,255;carica il wdog
        ld      a,vol1  ;
        cpi     a,30    ;
        jrz     m1      ;
        call    volup   ;
        ld      vol1,a  ;
        jp      n1      ;
m1      jp      tasto2  ;
n1      res     2,port_a
	call    alza
	set     2,port_a
	nop
	set     1,port_a

tasto2
; * * * * * * * * * * * * * * * * * * * * 

	jp      main1
;
;

;****************************************************************************
;*                     VETTORI DI INTERRUPTS                                *
;****************************************************************************

; Questa parte deve essere riportata alla fine del MAIN e prima della
; istruzione finale .END .
; Queste istruzioni non dovranno essere modificate.


	.org    0ff0h
	jp      ad_int
	jp      tim_int
	jp      BC_int
	jp      A_int
	.org    0ffch
	jp      nmi_int
	jp      inizio

	.end    ;termine del programma
